[Libreoffice-commits] core.git: include/svx

Philipp Weissenbacher p.weissenbacher at gmail.com
Sat Aug 15 20:20:34 PDT 2015


 include/svx/svdmark.hxx  |    6 +-
 include/svx/svdobj.hxx   |   79 +++++++++++++++++++----------------
 include/svx/svdograf.hxx |   20 ++++----
 include/svx/svdpagv.hxx  |  106 +++++++++++++++++++++++------------------------
 include/svx/svdpoev.hxx  |   10 ++--
 5 files changed, 117 insertions(+), 104 deletions(-)

New commits:
commit c0a7b924d020afdcfd61a8fd116b4dd2fbdab778
Author: Philipp Weissenbacher <p.weissenbacher at gmail.com>
Date:   Thu Aug 6 23:13:27 2015 +0200

    tdf#39468 Translate German comments - include/svx
    
    Also fix some whitespace and Doxygen comments
    
    Change-Id: I0a3440cdff2b1b74b2aa4572fc5c92c1525bfd61
    Reviewed-on: https://gerrit.libreoffice.org/17549
    Reviewed-by: Phillip Sz <phillip.szelat at gmail.com>
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Norbert Thiebaud <nthiebaud at gmail.com>

diff --git a/include/svx/svdmark.hxx b/include/svx/svdmark.hxx
index 391dbbd..cba0a75 100644
--- a/include/svx/svdmark.hxx
+++ b/include/svx/svdmark.hxx
@@ -37,7 +37,9 @@ class SdrPageView;
 typedef std::set<sal_uInt16> SdrUShortCont;
 
 
-// Everything a View needs to know about a selected object
+/**
+ * Everything a View needs to know about a selected object
+ */
 class SVX_DLLPUBLIC SdrMark : public sdr::ObjectUser
 {
 protected:
@@ -233,7 +235,7 @@ public:
     bool TakeBoundRect(SdrPageView* pPageView, Rectangle& rRect) const;
     bool TakeSnapRect(SdrPageView* pPageView, Rectangle& rRect) const;
 
-    // Es werden saemtliche Entries kopiert!
+    // All Entries are copied!
     void operator=(const SdrMarkList& rLst);
 };
 
diff --git a/include/svx/svdograf.hxx b/include/svx/svdograf.hxx
index 1029b55..31a9965 100644
--- a/include/svx/svdograf.hxx
+++ b/include/svx/svdograf.hxx
@@ -39,7 +39,9 @@ namespace sdr
     } // end of namespace contact
 } // end of namespace sdr
 
-/* options for GetTransformedGraphic() */
+/**
+ * Options for GetTransformedGraphic()
+ */
 enum class SdrGrafObjTransformsAttrs
 {
     NONE       = 0x00,
@@ -85,19 +87,19 @@ private:
     virtual sdr::contact::ViewContact* CreateObjectSpecificViewContact() SAL_OVERRIDE;
     virtual sdr::properties::BaseProperties* CreateObjectSpecificProperties() SAL_OVERRIDE;
 
-    void                    ImpSetAttrToGrafInfo(); // Werte vom Pool kopieren
-    GraphicAttr             aGrafInfo;
+    void ImpSetAttrToGrafInfo(); // Copy values from the pool
+    GraphicAttr aGrafInfo;
 
-    OUString aFileName;          // Wenn es sich um einen Link handelt, steht hier der Dateiname drin.
+    OUString aFileName; // If it's a Link, the filename can be found in here
     OUString aReferer;
     OUString aFilterName;
-    GraphicObject*          pGraphic;           // Zur Beschleunigung von Bitmapausgaben, besonders von gedrehten.
-    GraphicObject*          mpReplacementGraphic;
-    SdrGraphicLink*         pGraphicLink;       // Und hier noch ein Pointer fuer gelinkte Grafiken
-    bool                    bMirrored:1;        // True bedeutet, die Grafik ist horizontal, d.h. ueber die Y-Achse gespiegelt auszugeben.
+    GraphicObject* pGraphic; // In order to speed up output of bitmaps, especially rotated ones
+    GraphicObject* mpReplacementGraphic;
+    SdrGraphicLink* pGraphicLink; // And here a pointer for linked graphics
+    bool bMirrored:1; // True: the graphic is horizontal, which means it's mirrored along the y-axis
 
     // #111096#
-    // Flag for allowing text animation. Default is sal_true.
+    // Flag for allowing text animation. Default is true.
     bool mbGrafAnimationAllowed:1;
 
     // #i25616#
diff --git a/include/svx/svdpagv.hxx b/include/svx/svdpagv.hxx
index 6d30747..5019b60 100644
--- a/include/svx/svdpagv.hxx
+++ b/include/svx/svdpagv.hxx
@@ -65,23 +65,23 @@ typedef ::std::vector< SdrPageWindow* > SdrPageWindowVector;
 class SVX_DLLPUBLIC SdrPageView
 {
 private:
-    SdrView& mrView;
-    SdrPage* mpPage;
-    Point         aPgOrg;   // Nullpunkt der Page
+    SdrView&     mrView;
+    SdrPage*     mpPage;
+    Point        aPgOrg;   // The Page's point of origin
 
-    Rectangle     aMarkBound; // wird
-    Rectangle     aMarkSnap;  // von
-    bool          mbHasMarked;
-    bool          mbVisible;
+    Rectangle    aMarkBound;
+    Rectangle    aMarkSnap;
+    bool         mbHasMarked;
+    bool         mbVisible;
 
-    SetOfByte    aLayerVisi;   // Menge der sichtbaren Layer
-    SetOfByte    aLayerLock;   // Menge der nicht editierbaren Layer
-    SetOfByte    aLayerPrn;    // Menge der druckbaren Layer
+    SetOfByte    aLayerVisi;   // Set of visible Layers
+    SetOfByte    aLayerLock;   // Set of non-editable Layers
+    SetOfByte    aLayerPrn;    // Set of printable Layers
 
-    SdrObjList*  pAktList;     // Aktuelle Liste, in der Regel die Page.
-    SdrObject*   pAktGroup;    // Aktuelle Gruppe. NULL=Keine.
+    SdrObjList*  pAktList;     // Current List, usually the Page
+    SdrObject*   pAktGroup;    // Current Group; nullptr means none
 
-    SdrHelpLineList aHelpLines; // Hilfslinien und -punkte
+    SdrHelpLineList aHelpLines; // Helper lines and points
 
     // #103911# Use one reserved slot (bReserveBool2) for the document color
     Color         maDocumentColor;
@@ -106,12 +106,12 @@ public:
     SdrPageWindow* FindPageWindow( const OutputDevice& rOutDev ) const;
     SdrPageWindow* GetPageWindow(sal_uInt32 nIndex) const;
 
-    /** finds the page window whose PaintWindow belongs to the given output device
-
-        In opposite to FindPageWindow, this method also cares possibly patched PaintWindow instances.
-        That is, a SdrPageWindow might have an original, and a patched SdrPaintWindow instance - if
-        this is the case, then the original SdrPaintWindow is examined before the patched one.
-    */
+    /**
+     * Finds the page window whose PaintWindow belongs to the given output device
+     * In opposite to FindPageWindow, this method also cares possibly patched PaintWindow instances.
+     * That is, a SdrPageWindow might have an original, and a patched SdrPaintWindow instance - if
+     * this is the case, then the original SdrPaintWindow is examined before the patched one.
+     */
     const SdrPageWindow* FindPatchedPageWindow( const OutputDevice& rOutDev ) const;
 
 private:
@@ -122,7 +122,7 @@ private:
     void SetLayer(const OUString& rName, SetOfByte& rBS, bool bJa);
     bool IsLayer(const OUString& rName, const SetOfByte& rBS) const;
 
-    // Nachsehen, ob AktGroup noch Inserted ist.
+    /// Let's see if the current Group (pAktGroup) is still inserted
     void CheckAktGroup();
 
     void AdjHdl();
@@ -131,7 +131,7 @@ public:
     SdrPageView(SdrPage* pPage1, SdrView& rNewView);
     ~SdrPageView();
 
-    // Wird von der PaintView gerufen, wenn Modelaenderungen abgeschlossen sind
+    /// Is called by PaintView, when modal changes have finished
     void ModelHasChanged();
 
     void Show();
@@ -143,32 +143,31 @@ public:
     SdrView& GetView() { return mrView; }
     const SdrView& GetView() const { return mrView; }
 
-    /** looks up the control container belonging to given output device
-
-        @return
-            If the given output device belongs to one of the SdrPageViewWinRecs associated with this
-            SdrPageView instance, the XControlContainer for this output device is returned, <NULL/>
-            otherwise.
-    */
+    /**
+     * Looks up the control container belonging to given output device
+     * @return
+     *      If the given output device belongs to one of the SdrPageViewWinRecs associated with this
+     *      SdrPageView instance, the XControlContainer for this output device is returned, <NULL/>
+     *      otherwise.
+     */
     ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlContainer >
         GetControlContainer( const OutputDevice& _rDevice ) const;
 
-    /** sets all elements in the view which support a design and a alive mode into the given mode
-    */
+    /// Sets all elements in the view which support a design and a alive mode into the given mode
     void    SetDesignMode( bool _bDesignMode ) const;
 
     bool IsVisible() const { return mbVisible; }
 
-    // Invalidiert den gesamten Bereich der Page
+    /// Invalidates the Page's whole area
     void InvalidateAllWin();
 
-    // PrePaint call forwarded from app windows
+    /// PrePaint call forwarded from app windows
     void PrePaint();
 
-    // rReg bezieht sich auf's OutDev, nicht auf die Page
+    /// @param rReg refers to the OutDev and not to the Page
     void CompleteRedraw( SdrPaintWindow& rPaintWindow, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector = NULL );
 
-    // write access to mpPreparedPageWindow
+    /// Write access to mpPreparedPageWindow
     void setPreparedPageWindow(SdrPageWindow* pKnownTarget);
 
     void DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget = 0, sdr::contact::ViewObjectContactRedirector* pRedirector = 0L,
@@ -178,13 +177,13 @@ public:
     Rectangle GetPageRect() const;
     SdrPage* GetPage() const { return mpPage; }
 
-    // Betretene Liste rausreichen
+    /// Return current List
     SdrObjList* GetObjList() const { return pAktList; }
 
-    // Betretene Gruppe rausreichen
+    /// Return current Group
     SdrObject* GetAktGroup() const { return pAktGroup; }
 
-    // Betretene Gruppe und Liste setzen
+    /// Set current Group and List
     void SetAktGroupAndList(SdrObject* pNewGroup, SdrObjList* pNewList);
 
     bool HasMarkedObjPageView() const { return mbHasMarked; }
@@ -204,10 +203,10 @@ public:
     void SetLayerPrintable(const OUString& rName, bool bPrn = true) { SetLayer(rName, aLayerPrn, bPrn); }
     bool IsLayerPrintable(const OUString& rName) const { return IsLayer(rName, aLayerPrn); }
 
-    // PV stellt eine RefPage oder eine SubList eines RefObj dar oder Model ist ReadOnly
+    /// PV represents a RefPage or a SubList of a RefObj, or the Model is ReadOnly
     bool IsReadOnly() const;
 
-    // der Origin bezieht sich immer auf die obere linke Ecke der Page
+    /// The Origin always refers to the upper left corner of the Page
     const Point& GetPageOrigin() const { return aPgOrg; }
     void SetPageOrigin(const Point& rOrg);
 
@@ -229,29 +228,30 @@ public:
     void DeleteHelpLine(sal_uInt16 nNum);
     void InsertHelpLine(const SdrHelpLine& rHL, sal_uInt16 nNum=0xFFFF);
 
-    // Liefert sal_True, wenn Layer des Obj sichtbar und nicht gesperrt.
-    // Beim Gruppenobjekt muss wenigstens ein Member sichtbar sein,
-    // gesperrt sein darf keiner.
+    /// At least one member must be visible for the Group object and
+    /// it must not be locked
+    /// @returns
+    //       true, if the object's layer is visible and not locked
     bool IsObjMarkable(SdrObject* pObj) const;
-    // hmm, selectable is surely the same as markable, now that I
-    // see this as I look for a place to put it. TO-DO,
-    // merge these
-    bool IsObjSelectable(SdrObject *pObj) const;
 
+    /// Hmm, selectable is surely the same as markable, now that I
+    /// see this as I look for a place to put it.
+    /// TODO: merge these
+    bool IsObjSelectable(SdrObject *pObj) const;
 
-    // Betreten (Editieren) einer Objektgruppe. Anschliessend liegen alle
-    // Memberobjekte der Gruppe im direkten Zugriff. Alle anderen Objekte
-    // koennen waerendessen nicht bearbeitet werden (bis zum naechsten
-    // LeaveGroup()). (wie MsDos chdir bla).
+    /// Entering (editing) an object group
+    /// After that, we have direct access to all member objects of the group.
+    /// All other objects are not editable in the meantime (until the next
+    /// LeaveGroup())
     bool EnterGroup(SdrObject* pObj);
 
-    // Verlassen einer betretenen Objektgruppe. (wie MsDos chdir ..)
+    /// Leave an object group we entered previously
     void LeaveOneGroup();
 
-    // Verlassen aller betretenen Objektgruppen. (wie MsDos chdir \)
+    /// Leave all object groups we entered previously
     void LeaveAllGroup();
 
-    // Feststellen, wie weit hinabgestiegen wurde (0=Root(Page))
+    /// Determine, how deep we descended (0 = Root(Page))
     sal_uInt16 GetEnteredLevel() const;
 
     // #103834# Set background color for svx at SdrPageViews
diff --git a/include/svx/svdpoev.hxx b/include/svx/svdpoev.hxx
index 871c3f9..6aaf895 100644
--- a/include/svx/svdpoev.hxx
+++ b/include/svx/svdpoev.hxx
@@ -54,12 +54,12 @@ public:
     SdrPathSmoothKind GetMarkedPointsSmooth() const SAL_OVERRIDE;
     void SetMarkedPointsSmooth(SdrPathSmoothKind eKind) SAL_OVERRIDE;
 
-    // Ein PolySegment kann eine Strecke oder eine Bezierkurve sein.
+    // A PolySegment can either be a segment or a Bézier curve
     bool IsSetMarkedSegmentsKindPossible() const SAL_OVERRIDE;
     SdrPathSegmentKind GetMarkedSegmentsKind() const SAL_OVERRIDE;
     void SetMarkedSegmentsKind(SdrPathSegmentKind eKind) SAL_OVERRIDE;
 
-    // Moeglicherweise ist das Obj hinterher geloescht:
+    // Probably Obj has been deleted afterwards
     void DeleteMarkedPoints() SAL_OVERRIDE;
     bool IsDeleteMarkedPointsPossible() const SAL_OVERRIDE;
 
@@ -67,12 +67,12 @@ public:
     void ResizeMarkedPoints(const Point& rRef, const Fraction& xFact, const Fraction& yFact);
     void RotateMarkedPoints(const Point& rRef, long nAngle);
 
-    // Hierbei entstehen eventuell beliebig viele neue Objekte:
+    // This probably creates an abitrary amount of new objects
     void RipUpAtMarkedPoints() SAL_OVERRIDE;
     bool IsRipUpAtMarkedPointsPossible() const SAL_OVERRIDE;
 
-    // Alle markierten Polylines werden zu Polygonen, alle offenen
-    // Bezierkurven zu geschlossenen.
+    // All marked Polylines are turned into polygons
+    // All open Bézier curves are turned into closed ones
     bool IsOpenCloseMarkedObjectsPossible() const SAL_OVERRIDE;
     SdrObjClosedKind GetMarkedObjectsClosedState() const SAL_OVERRIDE;
 


More information about the Libreoffice-commits mailing list
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index 652cd9f..830cfed 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -179,9 +179,11 @@ public:
     SdrObjMacroHitRec();
 };
 
-// User data of a drawing object, e.g. application specific data.
-// Every drawing object can have arbitrarily many such records (SV list).
-// Whoever wants to save data here, must inherit from this and set a corresponding link in the factory.
+/**
+ * User data of a drawing object, e.g. application specific data.
+ * Every drawing object can have an arbitrary amount of such records (SV list).
+ * Whoever wants to save data here, must inherit from this and set a corresponding link in the factory.
+ */
 class SVX_DLLPUBLIC SdrObjUserData
 {
 protected:
@@ -204,7 +206,9 @@ public:
     sal_uInt16 GetId() const { return nIdentifier;}
 };
 
-// all geometrical data of an arbitrary object for use in undo/redo
+/**
+ * All geometrical data of an arbitrary object for use in undo/redo
+ */
 class SVX_DLLPUBLIC SdrObjGeoData
 {
 public:
@@ -223,7 +227,9 @@ public:
     virtual ~SdrObjGeoData();
 };
 
-// provides information about various ZObject properties
+/**
+ * Provides information about various ZObject properties
+ */
 class SVX_DLLPUBLIC SdrObjTransformInfoRec
 {
 public:
@@ -241,7 +247,7 @@ public:
     bool bShearAllowed : 1;            // if false, object cannot be sheared
     bool bEdgeRadiusAllowed : 1;
     bool bNoOrthoDesired : 1;          // is true for Rect; is false for BMP, MTF
-    bool bNoContortion : 1;            // if false, Kein verzerren (bei Crook) moeglich (nur true bei PathObj und Gruppierten PathObjs)
+    bool bNoContortion : 1;            // if false, contortion not possible (for crook, only true for PathObj and grouped PathObjs)
     bool bCanConvToPath : 1;           // if false, no conversion into PathObj possible
     bool bCanConvToPoly : 1;           // if false, no conversion into PolyObj possible
     bool bCanConvToContour : 1;        // if false, no conversion down to whole contour possible
@@ -251,7 +257,7 @@ public:
     SdrObjTransformInfoRec();
 };
 
-// Abstract DrawObject
+/// Abstract DrawObject
 
 class SvxShape;
 class SVX_DLLPUBLIC SdrObject: public SfxListener, public tools::WeakBase< SdrObject >
@@ -305,7 +311,7 @@ protected:
     SfxGrabBagItem*             pGrabBagItem; // holds the GrabBagItem property
 
 
-    // Position in the navigation order.  SAL_MAX_UINT32 when not used.
+    // Position in the navigation order. SAL_MAX_UINT32 when not used.
     sal_uInt32                  mnNavigationPosition;
     SdrLayerID                  mnLayerID;
 
@@ -321,12 +327,13 @@ protected:
     bool                        bSizProt : 1;   // if true, the size is protected
     bool                        bNoPrint : 1;   // if true, the object is not printed.
     bool                        mbVisible : 1;  // if false, the object is not visible on screen (but maybe on printer, depending on bNoprint
+
     // If bEmptyPresObj is true, it is a presentation object that has no content yet.
     // The flag's default value is false.
     // The management is done by the application.
     // Neither assign operator nor cloning copies the flag!
     // The flag is persistent.
-    bool                        bEmptyPresObj : 1;     // empty presentation object (Draw)
+    bool                        bEmptyPresObj : 1; // empty presentation object (Draw)
 
     // if true, object is invisible as object of the MasterPage
     bool                        bNotVisibleAsMaster : 1;
@@ -378,9 +385,10 @@ protected:
     OUString GetAngleStr(long nAngle, bool bNoDegChar = false) const;
     OUString GetMetrStr(long nVal, MapUnit eWantMap=MAP_MM, bool bNoUnitChars = false) const;
 
     // bNotMyself=true means: set only ObjList to dirty, don't mark this object as dirty.
     // This is needed for instance for NbcMove, because usually one moves SnapRect and aOutRect
     // at the same time to avoid recomputation.
 public:
     virtual void SetRectsDirty(bool bNotMyself = false);
 protected:
@@ -744,8 +752,8 @@ public:
     bool IsMacroHit(const SdrObjMacroHitRec& rRec) const;
 
     // Connectors
-    // (see also documentation in SvdoEdge.hxx, SdrEdgeObj,
-    // as well as SvdGlue.hxx and SvdGlEV.hxx)
+    // (see also documentation in SvdoEdge.hxx, SdrEdgeObj, as well as SvdGlue.hxx and SvdGlEV.hxx)
+    //
     // There are nodes and edges. In theory an edge can also be a node, but this isn't implemented yet.
     // A node has a number of glue points, onto which edges can glued to
     // An edge can be either
@@ -880,8 +888,8 @@ public:
     static SdrObject* getSdrObjectFromXShape( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& xInt );
 
     // sets a new UNO representation of the shape
-    //  This is only a public interface function. The actual work is
-    //  done by impl_setUnoShape().
+    // This is only a public interface function. The actual work is
+    // done by impl_setUnoShape().
     // Calling this function is only allowed for the UNO representation
     // itself!
     void setUnoShape(
@@ -895,15 +903,14 @@ public:
     //     There already exists an SvxShape instance associated with the SdrObject
     // @throws ::com::sun::star::uno::RuntimeException
     //     if there does nt yet exists an SvxShape instance associated with the SdrObject.
-    svx::PropertyChangeNotifier&
-        getShapePropertyChangeNotifier();
+    svx::PropertyChangeNotifier& getShapePropertyChangeNotifier();
 
     // notifies a change in the given property, to all applicable listeners registered at the associated SvxShape
     //
     // This method is equivalent to calling getShapePropertyChangeNotifier().notifyPropertyChange( _eProperty ),
     // exception that it is allowed to be called when there does not yet exist an associated SvxShape - in which
     // case the method will silently return without doing anything.
-    void    notifyShapePropertyChange( const svx::ShapeProperty _eProperty ) const;
+    void notifyShapePropertyChange( const svx::ShapeProperty _eProperty ) const;
 
     // transformation interface for StarOfficeAPI. This implements support for
     // homogen 3x3 matrices containing the transformation of the SdrObject. At the
@@ -947,16 +954,16 @@ public:
     virtual void dumpAsXml(struct _xmlTextWriter* pWriter) const;
 
 protected:
-    // Sets a new UNO shape
-    //
-    // The default implementation of this function sets the new UNO
-    // shape. Derived classes should override the function to handle
-    // any other actions that are needed when the shape is being
-    // changed.
-    //
-    // The implementation _must_ call the same method of its parent
-    // class (preferably as the first step)!
-    virtual void    impl_setUnoShape( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxUnoShape );
+    /// Sets a new UNO shape
+    ///
+    /// The default implementation of this function sets the new UNO
+    /// shape. Derived classes should override the function to handle
+    /// any other actions that are needed when the shape is being
+    /// changed.
+    ///
+    /// The implementation _must_ call the same method of its parent
+    /// class (preferably as the first step)!
+    virtual void impl_setUnoShape( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxUnoShape );
 
     // helper function for reimplementing Clone().
     template< typename T > T* CloneHelper() const;
@@ -974,12 +981,14 @@ private:
     bool mbDoNotInsertIntoPageAutomatically;
 };
 
-// Whoever creates his own objects must set a link in the SdrObjFactory class.
-// The handler must have the following signature:
-//    void Hdl(SdrObjFactory*)
-// He must take a look at the referenced instance's nInventor and nIdentifier values,
-// and must create a new drawing object instance accordingly.
-// He must also make the pNewObj pointer reference to this instance.
+/**
+ * Whoever creates his own objects must set a link in the SdrObjFactory class.
+ * The handler must have the following signature:
+ *      void Hdl(SdrObjFactory*)
+ * He must take a look at the referenced instance's nInventor and nIdentifier values,
+ * and must create a new drawing object instance accordingly.
+ * He must also make the pNewObj pointer reference to this instance.
+ */
 class SVX_DLLPUBLIC SdrObjFactory
 {
 public:
@@ -378,9 +385,10 @@ protected:
     OUString GetMetrStr(long nVal, MapUnit eWantMap=MAP_MM, bool bNoUnitChars = false) const;
 
-    // bNotMyself=true means: set only ObjList to dirty, don't mark this object as dirty.
-    // This is needed for instance for NbcMove, because usually one moves SnapRect and aOutRect
-    // at the same time to avoid recomputation.
+    /// @param bNotMyself = true: set only ObjList to dirty, don't mark this object as dirty.
+    ///
+    /// This is needed for instance for NbcMove, because usually one moves SnapRect and aOutRect
+    /// at the same time to avoid recomputation.
 public:
     virtual void SetRectsDirty(bool bNotMyself = false);